@@ -27,6 +27,25 @@ def _annotate_math_functions(self: TypeAnnotator, expression: exp.Expression) ->
     return expression
 
 
+def _annotate_safe_divide(self: TypeAnnotator, expression: exp.SafeDivide) -> exp.Expression:
+    """
+    +------------+------------+------------+-------------+---------+
+    | INPUT      | INT64      | NUMERIC    | BIGNUMERIC  | FLOAT64 |
+    +------------+------------+------------+-------------+---------+
+    | INT64      | FLOAT64    | NUMERIC    | BIGNUMERIC  | FLOAT64 |
+    | NUMERIC    | NUMERIC    | NUMERIC    | BIGNUMERIC  | FLOAT64 |
+    | BIGNUMERIC | BIGNUMERIC | BIGNUMERIC | BIGNUMERIC  | FLOAT64 |
+    | FLOAT64    | FLOAT64    | FLOAT64    | FLOAT64     | FLOAT64 |
+    +------------+------------+------------+-------------+---------+
+    """
+    if expression.this.is_type(*exp.DataType.INTEGER_TYPES) and expression.expression.is_type(
+        *exp.DataType.INTEGER_TYPES
+    ):
+        return self._set_type(expression, exp.DataType.Type.DOUBLE)
+
+    return _annotate_by_args_with_coerce(self, expression)
+
+
 def _annotate_by_args_with_coerce(
     self: TypeAnnotator, expression: exp.Expression
 ) -> exp.Expression:
@@ -144,9 +163,9 @@ EXPRESSION_METADATA = {
     **{
         expr_type: {"annotator": lambda self, e: self._annotate_by_args(e, "this")}
         for expr_type in {
-            exp.Abs,
             exp.ArgMax,
             exp.ArgMin,
+            exp.DateAdd,
             exp.DateTrunc,
             exp.DatetimeTrunc,
             exp.FirstValue,
@@ -156,6 +175,7 @@ EXPRESSION_METADATA = {
             exp.Lead,
             exp.Left,
             exp.Lower,
+            exp.NetFunc,
             exp.NthValue,
             exp.Pad,
             exp.PercentileDisc,
@@ -166,6 +186,7 @@ EXPRESSION_METADATA = {
             exp.RespectNulls,
             exp.Reverse,
             exp.Right,
+            exp.SafeFunc,
             exp.SafeNegate,
             exp.Sign,
             exp.Substring,
@@ -178,7 +199,6 @@ EXPRESSION_METADATA = {
     **{
         expr_type: {"returns": exp.DataType.Type.BIGINT}
         for expr_type in {
-            exp.Ascii,
             exp.BitwiseAndAgg,
             exp.BitwiseCount,
             exp.BitwiseOrAgg,
@@ -194,7 +214,6 @@ EXPRESSION_METADATA = {
             exp.RangeBucket,
             exp.RegexpInstr,
             exp.RowNumber,
-            exp.Unicode,
         }
     },
     **{
@@ -236,7 +255,6 @@ EXPRESSION_METADATA = {
             exp.Atan,
             exp.Atan2,
             exp.Atanh,
-            exp.Cbrt,
             exp.Corr,
             exp.CosineDistance,
             exp.Cot,
@@ -283,13 +301,14 @@ EXPRESSION_METADATA = {
         for expr_type in {
             exp.CodePointsToString,
             exp.Format,
+            exp.Host,
             exp.JSONExtractScalar,
             exp.JSONType,
             exp.LaxString,
             exp.LowerHex,
             exp.MD5,
-            exp.NetHost,
             exp.Normalize,
+            exp.RegDomain,
             exp.SafeConvertBytesToString,
             exp.Soundex,
             exp.Uuid,
@@ -317,16 +336,11 @@ EXPRESSION_METADATA = {
     **{
         expr_type: {"returns": exp.DataType.Type.TIMESTAMPTZ} for expr_type in TIMESTAMP_EXPRESSIONS
     },
-    exp.DateFromUnixDate: {"returns": exp.DataType.Type.DATE},
-    exp.ParseBignumeric: {"returns": exp.DataType.Type.BIGDECIMAL},
-    exp.ParseNumeric: {"returns": exp.DataType.Type.DECIMAL},
     exp.ApproxTopK: {"annotator": lambda self, e: _annotate_by_args_approx_top(self, e)},
     exp.ApproxTopSum: {"annotator": lambda self, e: _annotate_by_args_approx_top(self, e)},
     exp.Array: {"annotator": _annotate_array},
-    exp.ArrayConcat: {
-        "annotator": lambda self, e: self._annotate_by_args(e, "this", "expressions")
-    },
     exp.Concat: {"annotator": _annotate_concat},
+    exp.DateFromUnixDate: {"returns": exp.DataType.Type.DATE},
     exp.GenerateTimestampArray: {
         "annotator": lambda self, e: self._set_type(
             e, exp.DataType.build("ARRAY<TIMESTAMP>", dialect="bigquery")
@@ -348,6 +362,9 @@ EXPRESSION_METADATA = {
         )
     },
     exp.Lag: {"annotator": lambda self, e: self._annotate_by_args(e, "this", "default")},
+    exp.ParseBignumeric: {"returns": exp.DataType.Type.BIGDECIMAL},
+    exp.ParseNumeric: {"returns": exp.DataType.Type.DECIMAL},
+    exp.SafeDivide: {"annotator": lambda self, e: _annotate_safe_divide(self, e)},
     exp.ToCodePoints: {
         "annotator": lambda self, e: self._set_type(
             e, exp.DataType.build("ARRAY<BIGINT>", dialect="bigquery")
