@@ -22,6 +22,9 @@ DOUBLE;
 CURRENT_TIME();
 TIME;
 
+LOCALTIME();
+TIME;
+
 TIME_ADD(CAST('09:05:03' AS TIME), INTERVAL 2 HOUR);
 TIME;
 
@@ -128,6 +131,27 @@ BIGINT;
 UNIX_MILLIS(CAST('2008-12-25 15:30:00+00' AS TIMESTAMP));
 BIGINT;
 
+KURTOSIS(tbl.double_col);
+DOUBLE;
+
+KURTOSIS(tbl.int_col);
+DOUBLE;
+
+LENGTH(tbl.str_col);
+INT;
+
+LENGTH(tbl.bin_col);
+INT;
+
+DAYNAME(tbl.date_col);
+VARCHAR;
+
+CBRT(tbl.int_col);
+DOUBLE;
+
+CBRT(tbl.double_col);
+DOUBLE;
+
 # dialect: snowflake
 TO_BINARY('test');
 BINARY;
@@ -320,6 +344,278 @@ INTERVAL;
 COALESCE(tbl.bin_col, tbl.str_col);
 BINARY;
 
+# dialect: spark, databricks
+LOCALTIMESTAMP();
+TIMESTAMPNTZ;
+
+# dialect: hive, spark2, spark, databricks
+ENCODE(tbl.str_col, tbl.str_col);
+BINARY;
+
+# dialect: hive, spark2, spark, databricks
+ENCODE(tbl.bin_col, tbl.bin_col);
+BINARY;
+
+# dialect: spark, databricks
+CURRENT_TIMEZONE();
+STRING;
+
+# dialect: hive, spark2, spark, databricks
+UNIX_TIMESTAMP();
+BIGINT;
+
+# dialect: hive, spark2, spark, databricks
+ACOS(tbl.int_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+ACOS(tbl.double_col);
+DOUBLE;
+
+# dialect: spark2, spark, databricks
+ATAN2(tbl.int_col, tbl.int_col);
+DOUBLE;
+
+# dialect: spark2, spark, databricks
+ATAN2(tbl.double_col, tbl.double_col);
+DOUBLE;
+
+# dialect: spark2, spark, databricks
+ATAN2(tbl.double_col, tbl.int_col);
+DOUBLE;
+
+# dialect: spark, databricks
+ACOSH(tbl.double_col);
+DOUBLE;
+
+# dialect: spark, databricks
+ACOSH(tbl.int_col);
+DOUBLE;
+
+# dialect: spark2, spark, databricks
+COT(tbl.int_col);
+DOUBLE;
+
+# dialect: spark2, spark, databricks
+COT(tbl.double_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+COSH(tbl.double_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+COSH(tbl.int_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+SINH(tbl.double_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+SINH(tbl.int_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+TANH(tbl.double_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+TANH(tbl.int_col);
+DOUBLE;
+
+# dialect: spark, databricks
+TO_BINARY(tbl.str_col, tbl.str_col);
+BINARY;
+
+# dialect: spark, databricks
+TO_BINARY(tbl.int_col, tbl.str_col);
+BINARY;
+
+# dialect: spark, databricks
+TO_BINARY(tbl.double_col, tbl.str_col);
+BINARY;
+
+# dialect: hive, spark2, spark, databricks
+SHA(tbl.str_col);
+VARCHAR;
+
+# dialect: hive, spark2, spark, databricks
+SHA1(tbl.str_col);
+VARCHAR;
+
+# dialect: hive, spark2, spark, databricks
+SHA2(tbl.str_col, tbl.int_col);
+VARCHAR;
+
+# dialect: hive, spark2, spark, databricks
+SPACE(tbl.int_col);
+VARCHAR;
+
+# dialect: spark2, spark, databricks
+RANDN();
+DOUBLE;
+
+# dialect: spark2, spark, databricks
+BIT_LENGTH(tbl.str_col);
+INT;
+
+# dialect: hive, spark2, spark, databricks
+ASIN(tbl.int_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+ASIN(tbl.double_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+SIN(tbl.int_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+SIN(tbl.double_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+COS(tbl.int_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+COS(tbl.double_col);
+DOUBLE;
+
+# dialect: spark, databricks
+ASINH(tbl.int_col);
+DOUBLE;
+
+# dialect: spark, databricks
+ASINH(tbl.double_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+ATAN(tbl.int_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+ATAN(tbl.double_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+TAN(tbl.int_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+TAN(tbl.double_col);
+DOUBLE;
+
+# dialect: spark, databricks
+ATANH(tbl.double_col);
+DOUBLE;
+
+# dialect: spark, databricks
+ATANH(tbl.int_col);
+DOUBLE;
+
+# dialect: spark, databricks
+SEC(tbl.int_col);
+DOUBLE;
+
+# dialect: spark, databricks
+SEC(tbl.double_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+CORR(tbl.double_col, tbl.double_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+CORR(tbl.int_col, tbl.int_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+CBRT(tbl.double_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+CBRT(tbl.int_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+CURRENT_CATALOG();
+STRING;
+
+# dialect: hive, spark2, spark, databricks
+CURRENT_DATABASE();
+STRING;
+
+# dialect: spark, databricks
+DATE_FROM_UNIX_DATE(tbl.int_col);
+DATE;
+
+# dialect: hive, spark2, spark, databricks
+MONTHS_BETWEEN(tbl.timestamp_col, tbl.timestamp_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+MONTHS_BETWEEN(tbl.timestamp_col, tbl.timestamp_col, tbl.bool_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+MONTH(tbl.date_col);
+INT;
+
+# dialect: spark, databricks
+MONTHNAME(tbl.date_col);
+STRING;
+
+# dialect: hive, spark, databricks
+CURRENT_SCHEMA();
+STRING;
+
+# dialect: hive, spark2, spark, databricks
+CURRENT_USER();
+STRING;
+
+# dialect: hive, spark2, spark, databricks
+UNHEX(tbl.str_col);
+BINARY;
+
+# dialect: hive, spark2, spark, databricks
+HEX(tbl.str_col);
+STRING;
+
+# dialect: hive, spark2, spark, databricks
+HEX(tbl.int_col);
+STRING;
+
+# dialect: hive, spark2, spark, databricks
+SOUNDEX(tbl.str_col);
+STRING;
+
+# dialect: spark, databricks
+SESSION_USER();
+STRING;
+
+# dialect: hive, spark2, spark, databricks
+FACTORIAL(tbl.int_col);
+BIGINT;
+
+# dialect: spark, databricks
+ARRAY_SIZE(tbl.array_col);
+INT;
+
+# dialect: hive, spark2, spark, databricks
+QUARTER(tbl.date_col);
+INT;
+
+# dialect: hive, spark2, spark, databricks
+SECOND(tbl.timestamp_col);
+INT;
+
+# dialect: hive, spark2, spark, databricks
+MD5(tbl.str_col);
+STRING;
+
 --------------------------------------
 -- BigQuery
 --------------------------------------
@@ -430,7 +726,7 @@ BIGNUMERIC;
 
 # dialect: bigquery
 SAFE_DIVIDE(tbl.int_col, tbl.int_col);
-INT64;
+FLOAT64;
 
 # dialect: bigquery
 SAFE_DIVIDE(tbl.int_col, tbl.bignum_col);
@@ -464,6 +760,38 @@ FLOAT64;
 SAFE_DIVIDE(tbl.double_col, tbl.double_col);
 FLOAT64;
 
+# dialect: bigquery
+SAFE.TIMESTAMP(tbl.str_col);
+TIMESTAMPTZ;
+
+# dialect: bigquery
+TIMESTAMP(tbl.str_col);
+TIMESTAMPTZ;
+
+# dialect: bigquery
+SAFE.PARSE_DATE('%Y-%m-%d', '2024-01-15');
+DATE;
+
+# dialect: bigquery
+PARSE_DATE('%Y-%m-%d', '2024-01-15');
+DATE;
+
+# dialect: bigquery
+SAFE.PARSE_DATETIME('%Y-%m-%d %H:%M:%S', '2024-01-15 10:30:00');
+DATETIME;
+
+# dialect: bigquery
+SAFE.PARSE_TIME('%H:%M:%S', '10:30:00');
+TIME;
+
+# dialect: bigquery
+SAFE.PARSE_TIMESTAMP('%Y-%m-%d %H:%M:%S', '2024-01-15 10:30:00');
+TIMESTAMPTZ;
+
+# dialect: bigquery
+PARSE_TIMESTAMP('%Y-%m-%d %H:%M:%S', '2024-01-15 10:30:00');
+TIMESTAMPTZ;
+
 # dialect: bigquery
 CONCAT(tbl.str_col, tbl.str_col);
 STRING;
@@ -1100,6 +1428,10 @@ STRING;
 NET.HOST('http://example.com');
 STRING;
 
+# dialect: bigquery
+NET.REG_DOMAIN('http://example.com');
+STRING;
+
 # dialect: bigquery
 PERCENTILE_CONT(CAST(1 AS NUMERIC), CAST(1 AS NUMERIC)) OVER (ORDER BY 1);
 NUMERIC;
@@ -1668,6 +2000,14 @@ DATETIME;
 IF(TRUE, '00:00:00', TIME '00:01:00');
 TIME;
 
+# dialect: bigquery
+IF(TRUE, 1, CAST(2.5 AS BIGNUMERIC));
+BIGNUMERIC;
+
+# dialect: bigquery
+IF(TRUE, 1.5, 2.5);
+FLOAT64;
+
 # dialect: bigquery
 IF(TRUE, '2010-01-01 00:00:00', TIMESTAMP '2020-02-02 00:00:00');
 TIMESTAMP;
@@ -1696,6 +2036,70 @@ STRING;
 ANY_VALUE(c2::STRING HAVING MAX c1::INT64);
 STRING;
 
+# dialect: bigquery
+r'a';
+STRING;
+
+# dialect: bigquery
+DATE_ADD(DATE '2008-12-25', INTERVAL 5 DAY);
+DATE;
+
+# dialect: bigquery
+DATE_ADD(DATE '2008-12-25', INTERVAL 2 WEEK);
+DATE;
+
+# dialect: bigquery
+DATE_ADD(DATE '2008-12-25', INTERVAL 3 MONTH);
+DATE;
+
+# dialect: bigquery
+DATE_ADD(DATE '2008-12-25', INTERVAL 1 QUARTER);
+DATE;
+
+# dialect: bigquery
+DATE_ADD(DATE '2008-12-25', INTERVAL 2 YEAR);
+DATE;
+
+# dialect: bigquery
+DATE_ADD(TIMESTAMP '2008-12-25 15:30:00', INTERVAL 5 DAY);
+TIMESTAMP;
+
+# dialect: bigquery
+DATE_ADD(TIMESTAMP '2008-12-25 15:30:00', INTERVAL 2 HOUR);
+TIMESTAMP;
+
+# dialect: bigquery
+DATE_ADD(TIMESTAMP '2008-12-25 15:30:00', INTERVAL 30 MINUTE);
+TIMESTAMP;
+
+# dialect: bigquery
+DATE_ADD(DATETIME '2008-12-25 15:30:00', INTERVAL 5 DAY);
+DATETIME;
+
+# dialect: bigquery
+DATE_ADD(DATETIME '2008-12-25 15:30:00', INTERVAL 2 WEEK);
+DATETIME;
+
+# dialect: bigquery
+DATE_ADD(DATETIME '2008-12-25 15:30:00', INTERVAL 3 MONTH);
+DATETIME;
+
+# dialect: bigquery
+DATE_ADD(DATETIME '2008-12-25 15:30:00', INTERVAL 1 QUARTER);
+DATETIME;
+
+# dialect: bigquery
+DATE_ADD(DATETIME '2008-12-25 15:30:00', INTERVAL 2 YEAR);
+DATETIME;
+
+# dialect: bigquery
+DATE_ADD(DATETIME '2008-12-25 15:30:00', INTERVAL 2 HOUR);
+DATETIME;
+
+# dialect: bigquery
+DATE_ADD(DATETIME '2008-12-25 15:30:00', INTERVAL 30 MINUTE);
+DATETIME;
+
 --------------------------------------
 -- Snowflake
 --------------------------------------
@@ -1716,6 +2120,10 @@ DATE;
 ADD_MONTHS(tbl.timestamp_col, -1);
 TIMESTAMP;
 
+# dialect: snowflake
+ARRAY_CONSTRUCT();
+ARRAY;
+
 # dialect: snowflake
 ARRAY_CONSTRUCT_COMPACT();
 ARRAY;
@@ -1724,6 +2132,30 @@ ARRAY;
 ARRAY_CONSTRUCT_COMPACT(1, null, 2);
 ARRAY;
 
+# dialect: snowflake
+ARRAY_COMPACT([1, null, 2]);
+ARRAY;
+
+# dialect: snowflake
+ARRAY_APPEND([1, 2, 3], 4);
+ARRAY;
+
+# dialect: snowflake
+ARRAY_CAT([1, 2], [3, 4]);
+ARRAY;
+
+# dialect: snowflake
+ARRAY_PREPEND([2, 3, 4], 1);
+ARRAY;
+
+# dialect: snowflake
+ARRAY_REMOVE([1, 2, 3], 2);
+ARRAY;
+
+# dialect: snowflake
+ARRAYS_ZIP([1, 2], [3, 4]);
+ARRAY;
+
 # dialect: snowflake
 ASIN(tbl.double_col);
 DOUBLE;
@@ -1748,6 +2180,30 @@ DOUBLE;
 CBRT(tbl.double_col);
 DOUBLE;
 
+# dialect: snowflake
+CBRT(tbl.decfloat_col);
+DECFLOAT;
+
+# dialect: snowflake
+CBRT(tbl.int_col);
+DOUBLE;
+
+# dialect: snowflake
+COVAR_POP(tbl.double_col, tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+COVAR_SAMP(tbl.double_col, tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+COVAR_POP(tbl.double_col, tbl.double_col) OVER (PARTITION BY 1);
+DOUBLE;
+
+# dialect: snowflake
+COVAR_SAMP(tbl.double_col, tbl.double_col) OVER (PARTITION BY 1);
+DOUBLE;
+
 # dialect: snowflake
 AI_AGG('foo', 'bar');
 VARCHAR;
@@ -1793,7 +2249,15 @@ BASE64_DECODE_STRING('SGVsbG8gV29ybGQ=');
 VARCHAR;
 
 # dialect: snowflake
-BASE64_DECODE_STRING('SGVsbG8gV29ybGQ=', 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/');
+BASE64_DECODE_STRING('SGVsbG8gV29ybGQ=', '+/=');
+VARCHAR;
+
+# dialect: snowflake
+BASE64_ENCODE(tbl.bin_col);
+VARCHAR;
+
+# dialect: snowflake
+BASE64_ENCODE('Hello World');
 VARCHAR;
 
 # dialect: snowflake
@@ -1801,7 +2265,7 @@ BASE64_ENCODE('Hello World', 76);
 VARCHAR;
 
 # dialect: snowflake
-BASE64_ENCODE('Hello World', 76, 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/');
+BASE64_ENCODE('Hello World', 76, '+/=');
 VARCHAR;
 
 # dialect: snowflake
@@ -2457,15 +2921,143 @@ EQUAL_NULL(1, 2);
 BOOLEAN;
 
 # dialect: snowflake
-EXTRACT(YEAR, CAST('2024-05-09' AS DATE));
+EXTRACT(YEAR FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
 INT;
 
 # dialect: snowflake
-EXTRACT(MONTH FROM CAST('2024-05-09 08:50:57' AS TIMESTAMP));
+EXTRACT(QUARTER FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
 INT;
 
 # dialect: snowflake
-EXTRACT(MINUTE, CAST('08:50:57' AS TIME));
+EXTRACT(MONTH FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+INT;
+
+# dialect: snowflake
+EXTRACT(WEEK FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+INT;
+
+# dialect: snowflake
+EXTRACT(WEEKISO FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+INT;
+
+# dialect: snowflake
+EXTRACT(DAY FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+INT;
+
+# dialect: snowflake
+EXTRACT(DAYOFMONTH FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+INT;
+
+# dialect: snowflake
+EXTRACT(DAYOFWEEK FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+INT;
+
+# dialect: snowflake
+EXTRACT(DAYOFWEEKISO FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+INT;
+
+# dialect: snowflake
+EXTRACT(DAYOFYEAR FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+INT;
+
+# dialect: snowflake
+EXTRACT(YEAROFWEEK FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+INT;
+
+# dialect: snowflake
+EXTRACT(YEAROFWEEKISO FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+INT;
+
+# dialect: snowflake
+EXTRACT(HOUR FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+INT;
+
+# dialect: snowflake
+EXTRACT(MINUTE FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+INT;
+
+# dialect: snowflake
+EXTRACT(SECOND FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+INT;
+
+# dialect: snowflake
+EXTRACT(NANOSECOND FROM CAST('2026-01-06 11:45:00.123456789' AS TIMESTAMP_NTZ));
+BIGINT;
+
+# dialect: snowflake
+EXTRACT(EPOCH_SECOND FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+BIGINT;
+
+# dialect: snowflake
+EXTRACT(EPOCH_MILLISECOND FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+BIGINT;
+
+# dialect: snowflake
+EXTRACT(EPOCH_MICROSECOND FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+BIGINT;
+
+# dialect: snowflake
+EXTRACT(EPOCH_NANOSECOND FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+BIGINT;
+
+# dialect: snowflake
+EXTRACT(YEAR FROM CAST('2026-01-06' AS DATE));
+INT;
+
+# dialect: snowflake
+EXTRACT(QUARTER FROM CAST('2026-01-06' AS DATE));
+INT;
+
+# dialect: snowflake
+EXTRACT(MONTH FROM CAST('2026-01-06' AS DATE));
+INT;
+
+# dialect: snowflake
+EXTRACT(WEEK FROM CAST('2026-01-06' AS DATE));
+INT;
+
+# dialect: snowflake
+EXTRACT(WEEKISO FROM CAST('2026-01-06' AS DATE));
+INT;
+
+# dialect: snowflake
+EXTRACT(DAY FROM CAST('2026-01-06' AS DATE));
+INT;
+
+# dialect: snowflake
+EXTRACT(DAYOFMONTH FROM CAST('2026-01-06' AS DATE));
+INT;
+
+# dialect: snowflake
+EXTRACT(DAYOFWEEK FROM CAST('2026-01-06' AS DATE));
+INT;
+
+# dialect: snowflake
+EXTRACT(DAYOFWEEKISO FROM CAST('2026-01-06' AS DATE));
+INT;
+
+# dialect: snowflake
+EXTRACT(DAYOFYEAR FROM CAST('2026-01-06' AS DATE));
+INT;
+
+# dialect: snowflake
+EXTRACT(YEAROFWEEK FROM CAST('2026-01-06' AS DATE));
+INT;
+
+# dialect: snowflake
+EXTRACT(YEAROFWEEKISO FROM CAST('2026-01-06' AS DATE));
+INT;
+
+# dialect: snowflake
+EXTRACT(HOUR FROM CAST('11:45:00.123456789' AS TIME));
+INT;
+
+# dialect: snowflake
+EXTRACT(MINUTE FROM CAST('11:45:00.123456789' AS TIME));
+INT;
+
+# dialect: snowflake
+EXTRACT(SECOND FROM CAST('11:45:00.123456789' AS TIME));
 INT;
 
 # dialect: snowflake
@@ -2792,6 +3384,38 @@ VARCHAR;
 INSERT(tbl.bin_col, 1, 2, tbl.bin_col);
 BINARY;
 
+# dialect: snowflake
+KURTOSIS(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+KURTOSIS(tbl.double_col) OVER (PARTITION BY 1);
+DOUBLE;
+
+# dialect: snowflake
+KURTOSIS(tbl.float_col);
+DOUBLE;
+
+# dialect: snowflake
+KURTOSIS(tbl.float_col) OVER (PARTITION BY 1);
+DOUBLE;
+
+# dialect: snowflake
+KURTOSIS(tbl.int_col);
+NUMBER(38, 12);
+
+# dialect: snowflake
+KURTOSIS(tbl.int_col) OVER (PARTITION BY 1);
+NUMBER(38, 12);
+
+# dialect: snowflake
+KURTOSIS(tbl.decfloat_col);
+DECFLOAT;
+
+# dialect: snowflake
+KURTOSIS(tbl.decfloat_col) OVER (PARTITION BY 1);
+DECFLOAT;
+
 # dialect: snowflake
 LEAST(x::DECIMAL(18, 2));
 DECIMAL(18, 2);
@@ -2833,12 +3457,16 @@ LEN(tbl.bin_col);
 INT;
 
 # dialect: snowflake
-LENGTH(tbl.str_col);
-INT;
+LOCALTIMESTAMP;
+TIMESTAMPLTZ;
 
 # dialect: snowflake
-LENGTH(tbl.bin_col);
-INT;
+LOCALTIMESTAMP();
+TIMESTAMPLTZ;
+
+# dialect: snowflake
+LOCALTIMESTAMP(3);
+TIMESTAMPLTZ;
 
 # dialect: snowflake
 OCTET_LENGTH(tbl.str_col);
@@ -2944,6 +3572,34 @@ VARCHAR;
 LTRIM(NULL);
 VARCHAR;
 
+# dialect: snowflake
+MAP_CAT(CAST(col AS MAP(VARCHAR, VARCHAR)), CAST(col AS MAP(VARCHAR, VARCHAR)));
+MAP;
+
+# dialect: snowflake
+MAP_CONTAINS_KEY('k1', CAST(col AS MAP(VARCHAR, VARCHAR)));
+BOOLEAN;
+
+# dialect: snowflake
+MAP_DELETE(CAST(col AS MAP(VARCHAR, VARCHAR)), 'b');
+MAP;
+
+# dialect: snowflake
+MAP_INSERT(CAST(col AS MAP(VARCHAR, VARCHAR)), 'b', '2');
+MAP;
+
+# dialect: snowflake
+MAP_KEYS(CAST(col AS MAP(VARCHAR, VARCHAR)));
+ARRAY;
+
+# dialect: snowflake
+MAP_PICK(CAST(col AS MAP(VARCHAR, VARCHAR)), 'a', 'c');
+MAP;
+
+# dialect: snowflake
+MAP_SIZE(CAST(col AS MAP(VARCHAR, VARCHAR)));
+INT;
+
 # dialect: snowflake
 MINUTE(CAST('08:50:57' AS TIME));
 INT;
@@ -3192,6 +3848,18 @@ DOUBLE;
 REGR_SLOPE(tbl.decfloat_col, tbl.decfloat_col);
 DECFLOAT;
 
+# dialect: snowflake
+REGR_VALX(NULL, 2.0);
+DOUBLE;
+
+# dialect: snowflake
+REGR_VALX(NULL, NULL);
+DOUBLE;
+
+# dialect: snowflake
+REGR_VALX(2.0, NULL);
+DOUBLE;
+
 # dialect: snowflake
 REGR_VALX(1.0, 2.0);
 DOUBLE;
@@ -3568,6 +4236,222 @@ DECFLOAT;
 TRY_TO_DECFLOAT('invalid');
 DECFLOAT;
 
+# dialect: snowflake
+TRY_TO_BINARY('48656C6C6F');
+BINARY;
+
+# dialect: snowflake
+TRY_TO_BINARY('48656C6C6F', 'HEX');
+BINARY;
+
+# dialect: snowflake
+TRY_TO_BOOLEAN('true');
+BOOLEAN;
+
+# dialect: snowflake
+TO_DATE('2024-01-31');
+DATE;
+
+# dialect: snowflake
+TO_DATE('2024-01-31', 'AUTO');
+DATE;
+
+# dialect: snowflake
+TRY_TO_DATE('2024-01-31');
+DATE;
+
+# dialect: snowflake
+TRY_TO_DATE('2024-01-31', 'AUTO');
+DATE;
+
+# dialect: snowflake
+TO_DECIMAL('123.45');
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TO_DECIMAL('123.45', '999.99');
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TO_DECIMAL('123.45', '999.99', 10, 2);
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TRY_TO_DECIMAL('123.45');
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TRY_TO_DECIMAL('123.45', '999.99');
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TRY_TO_DECIMAL('123.45', '999.99', 10, 2);
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TO_DOUBLE('123.456');
+DOUBLE;
+
+# dialect: snowflake
+TO_DOUBLE('123.456', '999.99');
+DOUBLE;
+
+# dialect: snowflake
+TRY_TO_DOUBLE('123.456');
+DOUBLE;
+
+# dialect: snowflake
+TRY_TO_DOUBLE('123.456', '999.99');
+DOUBLE;
+
+# dialect: snowflake
+TO_FILE(tbl.obj_col);
+FILE;
+
+# dialect: snowflake
+TO_FILE('file.csv');
+FILE;
+
+# dialect: snowflake
+TO_FILE('file.csv', '/relativepath/');
+FILE;
+
+# dialect: snowflake
+TRY_TO_FILE(tbl.obj_col);
+FILE;
+
+# dialect: snowflake
+TRY_TO_FILE('file.csv');
+FILE;
+
+# dialect: snowflake
+TRY_TO_FILE('file.csv', '/relativepath/');
+FILE;
+
+# dialect: snowflake
+TO_NUMBER('123.45');
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TO_NUMBER('123.45', '999.99');
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TO_NUMBER('123.45', '999.99', 10, 2);
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TRY_TO_NUMBER('123.45');
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TRY_TO_NUMBER('123.45', '999.99');
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TRY_TO_NUMBER('123.45', '999.99', 10, 2);
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TRY_TO_NUMERIC('123.45');
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TRY_TO_NUMERIC('123.45', '999.99');
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TRY_TO_NUMERIC('123.45', '999.99', 10, 2);
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TO_TIME('12:30:00');
+TIME;
+
+# dialect: snowflake
+TO_TIME('12:30:00', 'AUTO');
+TIME;
+
+# dialect: snowflake
+TRY_TO_TIME('12:30:00');
+TIME;
+
+# dialect: snowflake
+TRY_TO_TIME('12:30:00', 'AUTO');
+TIME;
+
+# dialect: snowflake
+TO_TIME('093000', 'HH24MISS');
+TIME;
+
+# dialect: snowflake
+TRY_TO_TIME('093000', 'HH24MISS');
+TIME;
+
+# dialect: snowflake
+TO_TIMESTAMP('2024-01-15 12:30:00');
+TIMESTAMP;
+
+# dialect: snowflake
+TO_TIMESTAMP('2024-01-15 12:30:00', 'AUTO');
+TIMESTAMP;
+
+# dialect: snowflake
+TO_TIMESTAMP_LTZ('2024-01-15 12:30:00');
+TIMESTAMPLTZ;
+
+# dialect: snowflake
+TO_TIMESTAMP_LTZ('2024-01-15 12:30:00', 'AUTO');
+TIMESTAMPLTZ;
+
+# dialect: snowflake
+TO_TIMESTAMP_NTZ('2024-01-15 12:30:00');
+TIMESTAMPNTZ;
+
+# dialect: snowflake
+TO_TIMESTAMP_NTZ('2024-01-15 12:30:00', 'AUTO');
+TIMESTAMPNTZ;
+
+# dialect: snowflake
+TO_TIMESTAMP_TZ('2024-01-15 12:30:00');
+TIMESTAMPTZ;
+
+# dialect: snowflake
+TO_TIMESTAMP_TZ('2024-01-15 12:30:00', 'AUTO');
+TIMESTAMPTZ;
+
+# dialect: snowflake
+TRY_TO_TIMESTAMP('2024-01-15 12:30:00');
+TIMESTAMP;
+
+# dialect: snowflake
+TRY_TO_TIMESTAMP('2024-01-15 12:30:00', 'AUTO');
+TIMESTAMP;
+
+# dialect: snowflake
+TRY_TO_TIMESTAMP_LTZ('2024-01-15 12:30:00');
+TIMESTAMPLTZ;
+
+# dialect: snowflake
+TRY_TO_TIMESTAMP_LTZ('2024-01-15 12:30:00', 'AUTO');
+TIMESTAMPLTZ;
+
+# dialect: snowflake
+TRY_TO_TIMESTAMP_NTZ('2024-01-15 12:30:00');
+TIMESTAMPNTZ;
+
+# dialect: snowflake
+TRY_TO_TIMESTAMP_NTZ('2024-01-15 12:30:00', 'AUTO');
+TIMESTAMPNTZ;
+
+# dialect: snowflake
+TRY_TO_TIMESTAMP_TZ('2024-01-15 12:30:00');
+TIMESTAMPTZ;
+
+# dialect: snowflake
+TRY_TO_TIMESTAMP_TZ('2024-01-15 12:30:00', 'AUTO');
+TIMESTAMPTZ;
+
 # dialect: snowflake
 ABS(CAST(-123.456 AS DECFLOAT));
 DECFLOAT;
@@ -3848,6 +4732,30 @@ BOOLEAN;
 SEARCH_IP(col, '192.168.0.0');
 BOOLEAN;
 
+# dialect: snowflake
+STDDEV(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+STDDEV(tbl.double_col) OVER (PARTITION BY 1);
+DOUBLE;
+
+# dialect: snowflake
+STDDEV_POP(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+STDDEV_POP(tbl.double_col) OVER (PARTITION BY 1);
+DOUBLE;
+
+# dialect: snowflake
+STDDEV_SAMP(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+STDDEV_SAMP(tbl.double_col) OVER (PARTITION BY 1);
+DOUBLE;
+
 # dialect: snowflake
 STRTOK_TO_ARRAY('a,b,c', ',');
 ARRAY;
@@ -4444,6 +5352,118 @@ NUMBER(38, 15);
 VARIANCE_POP(1::NUMBER(30, 5));
 NUMBER(38, 12);
 
+# dialect: snowflake
+ENCRYPT(tbl.str_col, 'passphrase');
+BINARY;
+
+# dialect: snowflake
+ENCRYPT(tbl.str_col, 'passphrase', 'aad');
+BINARY;
+
+# dialect: snowflake
+ENCRYPT(tbl.str_col, 'passphrase', 'aad', 'AES-GCM');
+BINARY;
+
+# dialect: snowflake
+ENCRYPT_RAW(tbl.str_col, tbl.key_col, tbl.iv_col);
+BINARY;
+
+# dialect: snowflake
+ENCRYPT_RAW(tbl.str_col, tbl.key_col, tbl.iv_col, tbl.aad_col);
+BINARY;
+
+# dialect: snowflake
+ENCRYPT_RAW(tbl.str_col, tbl.key_col, tbl.iv_col, tbl.aad_col, 'AES-GCM');
+BINARY;
+
+# dialect: snowflake
+DECRYPT(tbl.encrypted_col, 'passphrase');
+BINARY;
+
+# dialect: snowflake
+DECRYPT(tbl.encrypted_col, 'passphrase', 'aad');
+BINARY;
+
+# dialect: snowflake
+DECRYPT(tbl.encrypted_col, 'passphrase', 'aad', 'AES-GCM');
+BINARY;
+
+# dialect: snowflake
+DECRYPT_RAW(tbl.encrypted_col, tbl.key_col, tbl.iv_col);
+BINARY;
+
+# dialect: snowflake
+DECRYPT_RAW(tbl.encrypted_col, tbl.key_col, tbl.iv_col, tbl.aad_col);
+BINARY;
+
+# dialect: snowflake
+DECRYPT_RAW(tbl.encrypted_col, tbl.key_col, tbl.iv_col, tbl.aad_col, 'AES-GCM');
+BINARY;
+
+# dialect: snowflake
+DECRYPT_RAW(tbl.encrypted_col, tbl.key_col, tbl.iv_col, tbl.aad_col, 'AES-GCM', HEX_DECODE_BINARY('ff'));
+BINARY;
+
+# dialect: snowflake
+TRY_DECRYPT(tbl.encrypted_col, 'passphrase');
+BINARY;
+
+# dialect: snowflake
+TRY_DECRYPT(tbl.encrypted_col, 'passphrase', 'aad');
+BINARY;
+
+# dialect: snowflake
+TRY_DECRYPT(tbl.encrypted_col, 'passphrase', 'aad', 'AES-GCM');
+BINARY;
+
+# dialect: snowflake
+TRY_DECRYPT_RAW(tbl.encrypted_col, tbl.key_col, tbl.iv_col);
+BINARY;
+
+# dialect: snowflake
+TRY_DECRYPT_RAW(tbl.encrypted_col, tbl.key_col, tbl.iv_col, tbl.aad_col);
+BINARY;
+
+# dialect: snowflake
+TRY_DECRYPT_RAW(tbl.encrypted_col, tbl.key_col, tbl.iv_col, tbl.aad_col, 'AES-GCM');
+BINARY;
+
+# dialect: snowflake
+TRY_DECRYPT_RAW(tbl.encrypted_col, tbl.key_col, tbl.iv_col, tbl.aad_col, 'AES-GCM', HEX_DECODE_BINARY('ff'));
+BINARY;
+
+# dialect: snowflake
+SEQ1();
+INT;
+
+# dialect: snowflake
+SEQ1(1);
+INT;
+
+# dialect: snowflake
+SEQ2();
+INT;
+
+# dialect: snowflake
+SEQ2(1);
+INT;
+
+# dialect: snowflake
+SEQ4();
+INT;
+
+# dialect: snowflake
+SEQ4(1);
+INT;
+
+# dialect: snowflake
+SEQ8();
+BIGINT;
+
+# dialect: snowflake
+SEQ8(1);
+BIGINT;
+
 --------------------------------------
 -- T-SQL
 --------------------------------------
@@ -4455,3 +5475,119 @@ TIMESTAMPTZ;
 # dialect: tsql
 RADIANS(90);
 INT;
+
+# dialect: tsql
+SIN(tbl.int_col);
+FLOAT;
+
+# dialect: tsql
+SIN(tbl.float_col);
+FLOAT;
+
+# dialect: tsql
+COS(tbl.int_col);
+FLOAT;
+
+# dialect: tsql
+COS(tbl.float_col);
+FLOAT;
+
+# dialect: tsql
+TAN(tbl.int_col);
+FLOAT;
+
+# dialect: tsql
+TAN(tbl.float_col);
+FLOAT;
+
+# dialect: tsql
+COT(tbl.int_col);
+FLOAT;
+
+# dialect: tsql
+COT(tbl.float_col);
+FLOAT;
+
+# dialect: tsql
+ATN2(tbl.int_col, tbl.int_col);
+FLOAT;
+
+# dialect: tsql
+ATN2(tbl.int_col, tbl.float_col);
+FLOAT;
+
+# dialect: tsql
+ATN2(tbl.float_col, tbl.int_col);
+FLOAT;
+
+# dialect: tsql
+ATN2(tbl.float_col, tbl.float_col);
+FLOAT;
+
+# dialect: tsql 
+ASIN(tbl.int_col);
+FLOAT;
+
+# dialect: tsql 
+ASIN(tbl.float_col);
+FLOAT;
+
+# dialect: tsql 
+ACOS(tbl.int_col);
+FLOAT;
+
+# dialect: tsql 
+ACOS(tbl.float_col);
+FLOAT;
+
+# dialect: tsql 
+ATAN(tbl.int_col);
+FLOAT;
+
+# dialect: tsql 
+ATAN(tbl.float_col);
+FLOAT;
+
+# dialect: tsql
+CURRENT_TIMEZONE();
+NVARCHAR;
+
+# dialect: tsql
+SOUNDEX(tbl.str_col);
+VARCHAR;
+
+--------------------------------------
+-- MySQL
+--------------------------------------
+
+# dialect: mysql
+LOCALTIME;
+DATETIME;
+
+# dialect: mysql
+ELT(1, 'a', 'b');
+VARCHAR;
+
+# dialect: mysql
+DAYOFWEEK(tbl.date_col);
+INT;
+
+--------------------------------------
+-- DuckDB
+--------------------------------------
+
+# dialect: duckdb
+SHA1(tbl.str_col);
+VARCHAR;
+
+# dialect: duckdb
+SHA256(tbl.str_col);
+VARCHAR;
+
+# dialect: duckdb 
+GET_BIT(tbl.str_col, tbl.int_col);
+INT;
+
+# dialect: duckdb
+FACTORIAL(tbl.int_col);
+HUGEINT
\ No newline at end of file
