@@ -1536,3 +1536,34 @@ FROM "t1" AS "t1"
 RIGHT JOIN "t2" AS "t2"
   ON "t1"."id1" = "t2"."id2"
 CROSS JOIN "t3" AS "t3";
+
+# title: subquery in GENERATE_SERIES stays untouched
+# execute: false
+WITH t3 AS (SELECT t1.c1::bigint AS ref1 FROM (SELECT MAX(x.a) as c1 FROM x) t1 JOIN GENERATE_SERIES((SELECT MAX(a) FROM x), 10, 1) AS t2(c1) on t2.c1 > t1.c1) SELECT * FROM t3;
+WITH "t1" AS (
+  SELECT
+    MAX("x"."a") AS "c1"
+  FROM "x" AS "x"
+)
+SELECT
+  CAST("t1"."c1" AS BIGINT) AS "ref1"
+FROM "t1" AS "t1"
+JOIN GENERATE_SERIES((
+  SELECT
+    MAX("x"."a") AS "_col_0"
+  FROM "x" AS "x"
+), 10, 1) AS "t2"("c1")
+  ON "t1"."c1" < "t2"."c1";
+
+# title: empty table right join GENERATE_SERIES should have data
+SELECT t1.c1 FROM z AS z RIGHT JOIN GENERATE_SERIES((SELECT MIN(x.a) FROM x), 10, 1) AS t1(c1) ON t1.c1 > z.c;
+SELECT
+  "t1"."c1" AS "c1"
+FROM "z" AS "z"
+RIGHT JOIN GENERATE_SERIES((
+  SELECT
+    MIN("x"."a") AS "_col_0"
+  FROM "x" AS "x"
+), 10, 1) AS "t1"("c1")
+  ON "t1"."c1" > "z"."c"
+;
\ No newline at end of file
